/** \file  main_pi_openmpi.c
 *  \brief Monte Carlo estimate of PI using openMpi
 */
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <mpi.h>

int 
main(int argc, char *argv[])
{
  int i, k, N;
  long nSteps;
  double x, y, locCtr, globCtr;

  MPI_Init(&argc, &argv);
  MPI_Comm_size(MPI_COMM_WORLD, &N);
  MPI_Comm_rank(MPI_COMM_WORLD, &k);
  nSteps = atoi(argv[1]);

  for (i = 0; i < (nSteps / N); i++) {
    x = drand48();
    y = drand48();
    if (x*x+y*y<1.) {
      locCtr += 1;
    }
  }

  MPI_Reduce(&locCtr, &globCtr, 1, MPI_DOUBLE, MPI_SUM, 0, MPI_COMM_WORLD);
  if (k == 0) {
    printf("number of processes = %d\n",N);
    printf("number of trials = %d\n",nSteps);
    printf("pi_estim = %f\n", 4*globCtr/nSteps);
  }

MPI_Finalize();
exit(0);
}
